@@ -39,14 +39,14 @@ void unfreeze (bool);	// Because FREEZE.H needs a load of other includes
 GLubyte * backdropTexture = NULL;
 GLuint backdropTextureName = 0;
 bool backdropExists = false;
-double backdropTexW = 1.0;
-double backdropTexH = 1.0;
+GLfloat backdropTexW = 1.0;
+GLfloat backdropTexH = 1.0;
 
 texture lightMap;
 
 GLuint snapshotTextureName = 0;
-double snapTexW = 1.0;
-double snapTexH = 1.0;
+float snapTexW = 1.0;
+float snapTexH = 1.0;
 
 int lightMapMode = LIGHTMAPMODE_PIXEL;
 
@@ -317,12 +317,21 @@ void blankScreen (int x1, int y1, int x2, int y2) {
 			glColor3ub(redValue(currentBlankColour), greenValue(currentBlankColour), blueValue(currentBlankColour));
 
 			glDisable (GL_TEXTURE_2D);
-			glBegin(GL_QUADS);
-			glVertex3f(-10.325, -1.325, 0.0);
-			glVertex3f(w+1.325, -1.325, 0.0);
-			glVertex3f(w+1.325, h+1.325, 0.0);
-			glVertex3f(-10.325, h+1.325, 0.0);
-			glEnd();
+
+			const GLfloat vertices[] = { 
+				-10.325f, -1.325f, 0.0f, 
+				w+1.325f, -1.325f, 0.0f, 
+				w+1.325f, h+1.325f, 0.0f, 
+				-10.325f, h+1.325f, 0.0f
+			};
+
+			glEnableClientState(GL_VERTEX_ARRAY);
+
+			glVertexPointer(3, GL_FLOAT, 0, vertices);
+
+			glDrawArrays(GL_QUADS, 0, 4);
+
+			glDisableClientState(GL_VERTEX_ARRAY);
 
 			// Copy Our ViewPort To The Texture
 			glBindTexture(GL_TEXTURE_2D, backdropTextureName);
@@ -344,6 +353,13 @@ void hardScroll (int distance) {
 
 	if (! distance) return;
 
+	const GLfloat backdropTexCoords[] = { 
+		0.0f, 0.0f,
+		backdropTexW, 0.0f,
+		backdropTexW, backdropTexH, 
+		0.0f, backdropTexH
+	}; 
+
 	setPixelCoords (true);
 
 	unsigned int xoffset = 0;
@@ -361,13 +377,23 @@ void hardScroll (int distance) {
 			glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
 			glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
 
-			glBegin(GL_QUADS);
-			glTexCoord2f(0.0, 0.0); glVertex3i(-xoffset, -distance-yoffset, 0);
-			glTexCoord2f(backdropTexW, 0.0); glVertex3i(sceneWidth-xoffset, -distance-yoffset, 0);
-			glTexCoord2f(backdropTexW, backdropTexH); glVertex3i(sceneWidth-xoffset, sceneHeight-distance-yoffset, 0);
-			glTexCoord2f(0.0, backdropTexH); glVertex3i(-xoffset, sceneHeight-distance-yoffset, 0);
-			glEnd();
+			const GLint vertices[] = { 
+				-xoffset, -distance-yoffset, 0, 
+				sceneWidth-xoffset, -distance-yoffset, 0, 
+				sceneWidth-xoffset, sceneHeight-distance-yoffset, 0, 
+				-xoffset, sceneHeight-distance-yoffset, 0
+			};
 
+			glEnableClientState(GL_VERTEX_ARRAY);
+			glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+
+			glVertexPointer(3, GL_INT, 0, vertices);
+			glTexCoordPointer(2, GL_FLOAT, 0, backdropTexCoords);
+
+			glDrawArrays(GL_QUADS, 0, 4);
+
+			glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+			glDisableClientState(GL_VERTEX_ARRAY);
 
 			// Copy Our ViewPort To The Texture
 			glBindTexture(GL_TEXTURE_2D, backdropTextureName);
@@ -406,12 +432,30 @@ void darkScreen () {
 			glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
 			glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
 
-			glBegin(GL_QUADS);
-			glTexCoord2f(0.0, 0.0); glVertex3f(-xoffset, -yoffset, 0.0);
-			glTexCoord2f(backdropTexW, 0.0); glVertex3f(sceneWidth-xoffset, -yoffset, 0.0);
-			glTexCoord2f(backdropTexW, backdropTexH); glVertex3f(sceneWidth-xoffset, sceneHeight-yoffset, 0.0);
-			glTexCoord2f(0.0, backdropTexH); glVertex3f(-xoffset, sceneHeight-yoffset, 0.0);
-			glEnd();
+			const GLint vertices[] = { 
+				-xoffset, -yoffset, 0, 
+				sceneWidth-xoffset, -yoffset, 0, 
+				sceneWidth-xoffset, sceneHeight-yoffset, 0, 
+				-xoffset, sceneHeight-yoffset, 0
+			};
+
+			const GLfloat texCoords[] = { 
+				0.0f, 0.0f,
+				backdropTexW, 0.0f,
+				backdropTexW, backdropTexH, 
+				0.0f, backdropTexH
+			}; 
+	
+			glEnableClientState(GL_VERTEX_ARRAY);
+			glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+
+			glVertexPointer(3, GL_INT, 0, vertices);
+			glTexCoordPointer(2, GL_FLOAT, 0, texCoords);
+
+			glDrawArrays(GL_QUADS, 0, 4);
+
+			glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+			glDisableClientState(GL_VERTEX_ARRAY);
 
 			// Then the darkness
 			glDisable (GL_TEXTURE_2D);
@@ -420,12 +464,11 @@ void darkScreen () {
 
 			glEnable(GL_BLEND);
 
-			glBegin(GL_QUADS);
-			glVertex3f(-xoffset, -yoffset, 0.0);
-			glVertex3f(sceneWidth-xoffset, -yoffset, 0.0);
-			glVertex3f(sceneWidth-xoffset, sceneHeight-yoffset, 0.0);
-			glVertex3f(-xoffset, sceneHeight-yoffset, 0.0);
-			glEnd();
+			glEnableClientState(GL_VERTEX_ARRAY);
+			glVertexPointer(3, GL_INT, 0, vertices);
+			glDrawArrays(GL_QUADS, 0, 4);
+			glDisableClientState(GL_VERTEX_ARRAY);
+
 			glDisable(GL_BLEND);
 			glColorMask (GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
 
@@ -476,7 +519,6 @@ void drawBackDrop () {
 			ps -> cameraY = sortOutPCamera (cameraY, ps -> fractionY, (int)(sceneHeight - (float)winHeight/cameraZoom), (int)(ps -> height - (float)winHeight/cameraZoom));
 
 			glBindTexture (GL_TEXTURE_2D, ps->textureName);
-			glBegin(GL_QUADS);
 
 			float w = (ps->wrapS) ? sceneWidth : ps->width;
 			float h = (ps->wrapT) ? sceneHeight : ps->height;
@@ -490,24 +532,62 @@ void drawBackDrop () {
 				texh = (ps->wrapT) ? (float) sceneHeight / ps->height: 1.0;
 			}
 
-			glTexCoord2f(0.0, 0.0); glVertex3f(-ps -> cameraX, -ps -> cameraY, 0.1);
-			glTexCoord2f(texw, 0.0); glVertex3f(w -ps -> cameraX, -ps -> cameraY, 0.1);
-			glTexCoord2f(texw, texh); glVertex3f(w -ps -> cameraX, h -ps -> cameraY, 0.1);
-			glTexCoord2f(0.0, texh); glVertex3f(-ps -> cameraX, h -ps -> cameraY, 0.1);
+			const GLfloat vertices[] = { 
+				(GLfloat)-ps -> cameraX, (GLfloat)-ps -> cameraY, 0.1f, 
+				w -ps -> cameraX, (GLfloat)-ps -> cameraY, 0.1f, 
+				w -ps -> cameraX, h -ps -> cameraY, 0.1f, 
+				(GLfloat)-ps -> cameraX, h -ps -> cameraY, 0.1f
+			};
 
-			glEnd();
+			const GLfloat texCoords[] = { 
+				0.0f, 0.0f,
+				texw, 0.0f,
+				texw, texh, 
+				0.0f, texh
+			}; 
+	
+			glEnableClientState(GL_VERTEX_ARRAY);
+			glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+
+			glVertexPointer(3, GL_FLOAT, 0, vertices);
+			glTexCoordPointer(2, GL_FLOAT, 0, texCoords);
+
+			glDrawArrays(GL_QUADS, 0, 4);
+
+			glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+			glDisableClientState(GL_VERTEX_ARRAY);
 
 			ps = ps -> prev;
 		}
 	}
 
 	glBindTexture (GL_TEXTURE_2D, backdropTextureName);
-	glBegin(GL_QUADS);
-	glTexCoord2f(0.0, 0.0); glVertex3f(-cameraX, -cameraY, 0.0);
-	glTexCoord2f(backdropTexW, 0.0); glVertex3f(sceneWidth-cameraX, -cameraY, 0.0);
-	glTexCoord2f(backdropTexW, backdropTexH); glVertex3f(sceneWidth-cameraX, sceneHeight-cameraY, 0.0);
-	glTexCoord2f(0.0, backdropTexH); glVertex3f(-cameraX, sceneHeight-cameraY, 0.0);
-	glEnd();
+
+	const GLfloat backdropTexCoords[] = { 
+		0.0f, 0.0f,
+		backdropTexW, 0.0f,
+		backdropTexW, backdropTexH, 
+		0.0f, backdropTexH
+	}; 
+
+	const GLint vertices[] = { 
+		-cameraX, -cameraY, 0, 
+		sceneWidth-cameraX, -cameraY, 0, 
+		sceneWidth-cameraX, sceneHeight-cameraY, 0, 
+		-cameraX, sceneHeight-cameraY, 0
+	};
+
+	glEnableClientState(GL_VERTEX_ARRAY);
+	glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+
+	glVertexPointer(3, GL_INT, 0, vertices);
+	glTexCoordPointer(2, GL_FLOAT, 0, backdropTexCoords);
+
+	glDrawArrays(GL_QUADS, 0, 4);
+
+	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+	glDisableClientState(GL_VERTEX_ARRAY);
+
 	glDisable(GL_BLEND);
 
 	glUseProgram(0);
@@ -966,8 +1046,8 @@ bool loadHSI (FILE * fp, int x, int y, bool reserve) {
 	}
 
 
-	double texCoordW = 1.0;
-	double texCoordH = 1.0;
+	GLfloat texCoordW = 1.0;
+	GLfloat texCoordH = 1.0;
 	if (! NPOT_textures) {
 		picWidth = getNextPOT(picWidth);
 		picHeight = getNextPOT(picHeight);
@@ -1056,6 +1136,12 @@ bool loadHSI (FILE * fp, int x, int y, bool reserve) {
 		bty2 = (float) (y+realPicHeight) / sceneHeight;
 	}
 
+	const GLfloat btexCoords[] = { 
+		btx1, bty1,
+		btx2, bty1,
+		btx2, bty2, 
+		btx1, bty2
+	}; 
 
 	setPixelCoords (true);
 
@@ -1069,11 +1155,29 @@ bool loadHSI (FILE * fp, int x, int y, bool reserve) {
 
 			glClear(GL_COLOR_BUFFER_BIT);	// Clear The Screen
 
+			const GLint vertices[] = { 
+				-xoffset, -yoffset, 0, 
+				realPicWidth-xoffset, -yoffset, 0, 
+				realPicWidth-xoffset, -yoffset+realPicHeight, 0, 
+				-xoffset, -yoffset+realPicHeight, 0
+			};
+
+			const GLfloat texCoords[] = { 
+				0.0f, 0.0f,
+				texCoordW, 0.0f,
+				texCoordW, texCoordH, 
+				0.0f, texCoordH
+			}; 
+
 			if (backdropExists) {
 				// Render the sprite to the backdrop
 				// (using mulitexturing, so the old backdrop is seen where alpha < 1.0)
+				glClientActiveTexture(GL_TEXTURE2);
 				glActiveTexture(GL_TEXTURE2);
 				glBindTexture (GL_TEXTURE_2D, backdropTextureName);
+				glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+				glTexCoordPointer(2, GL_FLOAT, 0, btexCoords);
+				glClientActiveTexture(GL_TEXTURE0);
 				glActiveTexture(GL_TEXTURE0);
 
 				glUseProgram(shader.paste);
@@ -1084,12 +1188,22 @@ bool loadHSI (FILE * fp, int x, int y, bool reserve) {
 				glBindTexture(GL_TEXTURE_2D, tmpTex);
 				glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
 
-				glBegin(GL_QUADS);
-				glTexCoord2f(0.0, 0.0); glMultiTexCoord2f(GL_TEXTURE2, btx1, bty1); 	glVertex3f(-xoffset, -yoffset, 0.0);
-				glTexCoord2f(texCoordW, 0.0); glMultiTexCoord2f(GL_TEXTURE2, btx2, bty1); 	glVertex3f(realPicWidth-xoffset, -yoffset, 0.0);
-				glTexCoord2f(texCoordW, texCoordH); glMultiTexCoord2f(GL_TEXTURE2, btx2, bty2); 	glVertex3f(realPicWidth-xoffset, realPicHeight-yoffset, 0.0);
-				glTexCoord2f(0.0, texCoordH); glMultiTexCoord2f(GL_TEXTURE2, btx1, bty2); 	glVertex3f(-xoffset, realPicHeight-yoffset, 0.0);
-				glEnd();
+				glEnableClientState(GL_VERTEX_ARRAY);
+				glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+
+				glVertexPointer(3, GL_INT, 0, vertices);
+				glTexCoordPointer(2, GL_FLOAT, 0, texCoords);
+
+				glDrawArrays(GL_QUADS, 0, 4);
+
+				glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+				glDisableClientState(GL_VERTEX_ARRAY);
+
+				glClientActiveTexture(GL_TEXTURE2);
+				glActiveTexture(GL_TEXTURE2);
+				glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+				glClientActiveTexture(GL_TEXTURE0);
+				glActiveTexture(GL_TEXTURE0);
 
 				glUseProgram(0);
 
@@ -1099,13 +1213,17 @@ bool loadHSI (FILE * fp, int x, int y, bool reserve) {
 				glBindTexture(GL_TEXTURE_2D, tmpTex);
 
 				glColor4f(1.0, 0.0, 0.0, 0.0);
-				glBegin(GL_QUADS);
-				glTexCoord2f(0.0, 0.0); glVertex3f(-xoffset, -yoffset, 0.0);
-				glTexCoord2f(texCoordW, 0.0); glVertex3f(realPicWidth-xoffset, -yoffset, 0.0);
-				glTexCoord2f(texCoordW, texCoordH); glVertex3f(realPicWidth-xoffset, -yoffset+realPicHeight, 0.0);
-				glTexCoord2f(0.0, texCoordH); glVertex3f(-xoffset, -yoffset+realPicHeight, 0.0);
-				glEnd();
 
+				glEnableClientState(GL_VERTEX_ARRAY);
+				glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+
+				glVertexPointer(3, GL_INT, 0, vertices);
+				glTexCoordPointer(2, GL_FLOAT, 0, texCoords);
+
+				glDrawArrays(GL_QUADS, 0, 4);
+
+				glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+				glDisableClientState(GL_VERTEX_ARRAY);
 			}
 
 			// Copy Our ViewPort To The Texture
@@ -1227,6 +1345,20 @@ bool mixHSI (FILE * fp, int x, int y) {
 		bty2 = (float) (y+picHeight) / sceneHeight;
 	}
 
+	const GLfloat texCoords[] = { 
+		tx1, ty1,
+		tx2, ty1,
+		tx2, ty2, 
+		tx1, ty2
+	}; 
+
+	const GLfloat btexCoords[] = { 
+		btx1, bty1,
+		btx2, bty1,
+		btx2, bty2, 
+		btx1, bty2
+	}; 
+
 	int t1, t2, n;
 	unsigned short c;
 	GLubyte * target;
@@ -1305,8 +1437,12 @@ bool mixHSI (FILE * fp, int x, int y) {
 
 			// Render the sprite to the backdrop
 			// (using mulitexturing, so the backdrop is seen where alpha < 1.0)
+			glClientActiveTexture(GL_TEXTURE2);
 			glActiveTexture(GL_TEXTURE2);
 			glBindTexture (GL_TEXTURE_2D, backdropTextureName);
+			glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+			glTexCoordPointer(2, GL_FLOAT, 0, btexCoords);
+			glClientActiveTexture(GL_TEXTURE0);
 			glActiveTexture(GL_TEXTURE0);
 
 			glUseProgram(shader.paste);
@@ -1317,12 +1453,29 @@ bool mixHSI (FILE * fp, int x, int y) {
 			glBindTexture(GL_TEXTURE_2D, tmpTex);
 			glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
 
-			glBegin(GL_QUADS);
-			glTexCoord2f(tx1, ty1); glMultiTexCoord2f(GL_TEXTURE2, btx1, bty1); 	glVertex3f(-xoffset, -yoffset, 0.0);
-			glTexCoord2f(tx2, ty1); glMultiTexCoord2f(GL_TEXTURE2, btx2, bty1); 	glVertex3f(realPicWidth-xoffset, -yoffset, 0.0);
-			glTexCoord2f(tx2, ty2); glMultiTexCoord2f(GL_TEXTURE2, btx2, bty2); 	glVertex3f(realPicWidth-xoffset, realPicHeight-yoffset, 0.0);
-			glTexCoord2f(tx1, ty2); glMultiTexCoord2f(GL_TEXTURE2, btx1, bty2); 	glVertex3f(-xoffset, realPicHeight-yoffset, 0.0);
-			glEnd();
+			const GLint vertices[] = { 
+				-xoffset, -yoffset, 0, 
+				realPicWidth-xoffset, -yoffset, 0, 
+				realPicWidth-xoffset, -yoffset+realPicHeight, 0, 
+				-xoffset, -yoffset+realPicHeight, 0
+			};
+
+			glEnableClientState(GL_VERTEX_ARRAY);
+			glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+
+			glVertexPointer(3, GL_INT, 0, vertices);
+			glTexCoordPointer(2, GL_FLOAT, 0, texCoords);
+
+			glDrawArrays(GL_QUADS, 0, 4);
+
+			glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+			glDisableClientState(GL_VERTEX_ARRAY);
+
+			glClientActiveTexture(GL_TEXTURE2);
+			glActiveTexture(GL_TEXTURE2);
+			glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+			glClientActiveTexture(GL_TEXTURE0);
+			glActiveTexture(GL_TEXTURE0);
 
 			// Copy Our ViewPort To The Texture
 			glBindTexture(GL_TEXTURE_2D, backdropTextureName);
@@ -1356,7 +1509,14 @@ void saveCorePNG  (FILE * writer, GLuint texture, int w, int h) {
 		
 	glEnable (GL_TEXTURE_2D);
 	glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
-	
+
+	const GLfloat texCoords[] = { 
+		0.0f, 0.0f,
+		1.0f, 0.0f,
+		1.0f, 1.0f, 
+		0.0f, 1.0f
+	}; 
+
 	int xoffset = 0;
 	while (xoffset < tw) {
 		int w = (tw-xoffset < viewportWidth) ? tw-xoffset : viewportWidth;
@@ -1366,14 +1526,25 @@ void saveCorePNG  (FILE * writer, GLuint texture, int w, int h) {
 			int h = (th-yoffset < viewportHeight) ? th-yoffset : viewportHeight;
 			
 			glClear(GL_COLOR_BUFFER_BIT);	// Clear The Screen
-			
-			glBegin(GL_QUADS);
-			glTexCoord2f(0.0, 0.0); glVertex3f(-xoffset, -yoffset, 0.0);
-			glTexCoord2f(1.0, 0.0); glVertex3f(tw-xoffset, -yoffset, 0.0);
-			glTexCoord2f(1.0, 1.0); glVertex3f(tw-xoffset, -yoffset+th, 0.0);
-			glTexCoord2f(0.0, 1.0); glVertex3f(-xoffset, -yoffset+th, 0.0);
-			glEnd();
-			
+
+			const GLint vertices[] = { 
+				-xoffset, -yoffset, 0, 
+				tw-xoffset, -yoffset, 0, 
+				tw-xoffset, -yoffset+th, 0, 
+				-xoffset, -yoffset+th, 0
+			};
+
+			glEnableClientState(GL_VERTEX_ARRAY);
+			glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+
+			glVertexPointer(3, GL_INT, 0, vertices);
+			glTexCoordPointer(2, GL_FLOAT, 0, texCoords);
+
+			glDrawArrays(GL_QUADS, 0, 4);
+
+			glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+			glDisableClientState(GL_VERTEX_ARRAY);
+
 			for (int i = 0; i<h; i++)	{
 				glReadPixels(viewportOffsetX, viewportOffsetY+i, w, 1, GL_RGBA, GL_UNSIGNED_BYTE, image+xoffset*4+(yoffset+i)*4*tw);
 			}
@@ -1437,6 +1608,13 @@ void saveCoreHSI (FILE * writer, GLuint texture, int w, int h) {
 	glEnable (GL_TEXTURE_2D);
 	glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
 	
+	const GLfloat texCoords[] = { 
+		0.0f, 0.0f,
+		1.0f, 0.0f,
+		1.0f, 1.0f, 
+		0.0f, 1.0f
+	}; 
+
 	int xoffset = 0;
 	while (xoffset < tw) {
 		int w = (tw-xoffset < viewportWidth) ? tw-xoffset : viewportWidth;
@@ -1446,13 +1624,24 @@ void saveCoreHSI (FILE * writer, GLuint texture, int w, int h) {
 			int h = (th-yoffset < viewportHeight) ? th-yoffset : viewportHeight;
 			
 			glClear(GL_COLOR_BUFFER_BIT);	// Clear The Screen
-			
-			glBegin(GL_QUADS);
-			glTexCoord2f(0.0, 0.0); glVertex3f(-xoffset, -yoffset, 0.0);
-			glTexCoord2f(1.0, 0.0); glVertex3f(w-xoffset, -yoffset, 0.0);
-			glTexCoord2f(1.0, 1.0); glVertex3f(w-xoffset, -yoffset+h, 0.0);
-			glTexCoord2f(0.0, 1.0); glVertex3f(-xoffset, -yoffset+h, 0.0);
-			glEnd();
+
+			const GLint vertices[] = { 
+				-xoffset, -yoffset, 0, 
+				w-xoffset, -yoffset, 0, 
+				w-xoffset, -yoffset+h, 0, 
+				-xoffset, -yoffset+h, 0
+			};
+
+			glEnableClientState(GL_VERTEX_ARRAY);
+			glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+
+			glVertexPointer(3, GL_INT, 0, vertices);
+			glTexCoordPointer(2, GL_FLOAT, 0, texCoords);
+
+			glDrawArrays(GL_QUADS, 0, 4);
+
+			glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+			glDisableClientState(GL_VERTEX_ARRAY);
 			
 			for (int i = 0; i<h; i++)	{
 				glReadPixels(viewportOffsetX, viewportOffsetY+i, w, 1, GL_RGB, GL_UNSIGNED_SHORT_5_6_5, image+xoffset+(yoffset+i)*tw);
